@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class RelationsConfig(AppConfig):
-    name = 'apis_relations'
+    name = "apis_core.apis_relations"
