@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class VocabulariesConfig(AppConfig):
-    name = 'apis_vocabularies'
+    name = "apis_core.apis_vocabularies"
